summaryrefslogtreecommitdiffstats
path: root/chrome/test/debugger
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/test/debugger')
-rw-r--r--chrome/test/debugger/debugger_unittests.py22
-rw-r--r--chrome/test/debugger/test_protocol.js8
2 files changed, 15 insertions, 15 deletions
diff --git a/chrome/test/debugger/test_protocol.js b/chrome/test/debugger/test_protocol.js
index 6ca0835..91abbf1 100644
--- a/chrome/test/debugger/test_protocol.js
+++ b/chrome/test/debugger/test_protocol.js
@@ -5,10 +5,10 @@
* @fileoverview Unit tests for testing debugger protocol betweeen front-end JS
* and back-end.
* Run with the following command line:
- * v8_shell.exe --allow-natives-syntax --expose-debug-as debugContext
- * chrome/browser/resources/shell.js
- * v8/tests/mjsunit.js
- * chrome/test/debugger/test_protocol.js
+ * v8_shell_sample.exe --allow-natives-syntax --expose-debug-as debugContext
+ * chrome/browser/resources/shell.js
+ * v8/tests/mjsunit.js
+ * chrome/test/debugger/test_protocol.js
*/
diff --git a/chrome/test/debugger/debugger_unittests.py b/chrome/test/debugger/debugger_unittests.py
index bdf22ea..ae962a0 100644
--- a/chrome/test/debugger/debugger_unittests.py
+++ b/chrome/test/debugger/debugger_unittests.py
@@ -13,23 +13,23 @@ import google.path_utils
import google.process_utils
def RunTests(build_dir=None):
- '''This is just a simple wrapper for running the test through v8_shell.
- Since v8_shell always returns 0 whether the test passes or fails, buildbot
- looks at stdout to test for failure.
+ '''This is just a simple wrapper for running the test through v8_shell_sample.
+ Since v8_shell_sample always returns 0 whether the test passes or fails,
+ buildbot looks at stdout to test for failure.
'''
script_dir = google.path_utils.ScriptDir()
chrome_dir = google.path_utils.FindUpward(script_dir, "chrome")
v8_dir = google.path_utils.FindUpward(script_dir, "v8")
if build_dir:
- v8_shell = os.path.join(build_dir, "v8_shell.exe")
+ v8_shell_sample = os.path.join(build_dir, "v8_shell_sample.exe")
else:
- v8_shell = os.path.join(chrome_dir, "Debug", "v8_shell.exe")
+ v8_shell_sample = os.path.join(chrome_dir, "Debug", "v8_shell_sample.exe")
# look for Debug version first
- if not os.path.isfile(v8_shell):
- v8_shell = os.path.join(chrome_dir, "Release", "v8_shell.exe")
- cmd = [v8_shell,
- "--allow-natives-syntax",
- "--expose-debug-as", "debugContext", # these two are together
+ if not os.path.isfile(v8_shell_sample):
+ v8_shell_sample = os.path.join(chrome_dir, "Release", "v8_shell_sample.exe")
+ runtime_flags = """--allow-natives-syntax --expose-debug-as debugContext"""
+ cmd = [v8_shell_sample,
+ "--runtime-flags", runtime_flags,
os.path.join(chrome_dir, "browser", "debugger", "resources", "debugger_shell.js"),
os.path.join(v8_dir, "tests", "mjsunit.js"),
os.path.join(chrome_dir, "test", "debugger", "test_protocol.js")
@@ -44,7 +44,7 @@ def RunTests(build_dir=None):
if __name__ == "__main__":
parser = optparse.OptionParser("usage: %prog [--build_dir=dir]")
parser.add_option("", "--build_dir",
- help="directory where v8_shell.exe was built")
+ help="directory where v8_shell_sample.exe was built")
(options, args) = parser.parse_args()
ret = RunTests(options.build_dir)
sys.exit(ret)